# mypy-boto3-inspector

[![PyPI - mypy-boto3-inspector](https://img.shields.io/pypi/v/mypy-boto3-inspector.svg?color=blue)](https://pypi.org/project/mypy-boto3-inspector)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-inspector.svg?color=blue)](https://pypi.org/project/mypy-boto3-inspector)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Inspector 1.17.36](https://boto3.amazonaws.com/v1/documentation/api/1.17.36/reference/services/inspector.html#Inspector) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-inspector](#mypy-boto3-inspector)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Inspector` service.

```bash
python -m pip install boto3-stubs[inspector]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[inspector]` in your environment: `python -m pip install 'boto3-stubs[inspector]'`

Both type checking and auto-complete should work for `Inspector` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[inspector]` in your environment: `python -m pip install 'boto3-stubs[inspector]'`

Both type checking and auto-complete should work for `Inspector` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[inspector]` in your environment: `python -m pip install 'boto3-stubs[inspector]'`
- Run `mypy` as usual

Type checking should work for `Inspector` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[inspector]` in your environment: `python -m pip install 'boto3-stubs[inspector]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Inspector` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`InspectorClient` provides annotations for `boto3.client("inspector")`.

```python
import boto3

from mypy_boto3_inspector import InspectorClient

client: InspectorClient = boto3.client("inspector")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: InspectorClient = session.client("inspector")
```

### Paginators annotations

`mypy_boto3_inspector.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_inspector import InspectorClient
from mypy_boto3_inspector.paginator import (
    ListAssessmentRunAgentsPaginator,
    ListAssessmentRunsPaginator,
    ListAssessmentTargetsPaginator,
    ListAssessmentTemplatesPaginator,
    ListEventSubscriptionsPaginator,
    ListExclusionsPaginator,
    ListFindingsPaginator,
    ListRulesPackagesPaginator,
    PreviewAgentsPaginator,
)

client: InspectorClient = boto3.client("inspector")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_assessment_run_agents_paginator: ListAssessmentRunAgentsPaginator = client.get_paginator("list_assessment_run_agents")
list_assessment_runs_paginator: ListAssessmentRunsPaginator = client.get_paginator("list_assessment_runs")
list_assessment_targets_paginator: ListAssessmentTargetsPaginator = client.get_paginator("list_assessment_targets")
list_assessment_templates_paginator: ListAssessmentTemplatesPaginator = client.get_paginator("list_assessment_templates")
list_event_subscriptions_paginator: ListEventSubscriptionsPaginator = client.get_paginator("list_event_subscriptions")
list_exclusions_paginator: ListExclusionsPaginator = client.get_paginator("list_exclusions")
list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
list_rules_packages_paginator: ListRulesPackagesPaginator = client.get_paginator("list_rules_packages")
preview_agents_paginator: PreviewAgentsPaginator = client.get_paginator("preview_agents")
```







### Typed dictionations

`mypy_boto3_inspector.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_inspector.type_defs import (
    AgentPreviewTypeDef,
    AssessmentRunAgentTypeDef,
    AssessmentRunNotificationTypeDef,
    AssessmentRunStateChangeTypeDef,
    AssessmentRunTypeDef,
    AssessmentTargetTypeDef,
    AssessmentTemplateTypeDef,
    AssetAttributesTypeDef,
    AttributeTypeDef,
    DurationRangeTypeDef,
    EventSubscriptionTypeDef,
    ExclusionPreviewTypeDef,
    ExclusionTypeDef,
    FailedItemDetailsTypeDef,
    FindingTypeDef,
    InspectorServiceAttributesTypeDef,
    NetworkInterfaceTypeDef,
    PrivateIpTypeDef,
    ResourceGroupTagTypeDef,
    ResourceGroupTypeDef,
    RulesPackageTypeDef,
    ScopeTypeDef,
    SecurityGroupTypeDef,
    SubscriptionTypeDef,
    TagTypeDef,
    TelemetryMetadataTypeDef,
    TimestampRangeTypeDef,
    AddAttributesToFindingsResponseTypeDef,
    AgentFilterTypeDef,
    AssessmentRunFilterTypeDef,
    AssessmentTargetFilterTypeDef,
    AssessmentTemplateFilterTypeDef,
    CreateAssessmentTargetResponseTypeDef,
    CreateAssessmentTemplateResponseTypeDef,
    CreateExclusionsPreviewResponseTypeDef,
    CreateResourceGroupResponseTypeDef,
    DescribeAssessmentRunsResponseTypeDef,
    DescribeAssessmentTargetsResponseTypeDef,
    DescribeAssessmentTemplatesResponseTypeDef,
    DescribeCrossAccountAccessRoleResponseTypeDef,
    DescribeExclusionsResponseTypeDef,
    DescribeFindingsResponseTypeDef,
    DescribeResourceGroupsResponseTypeDef,
    DescribeRulesPackagesResponseTypeDef,
    FindingFilterTypeDef,
    GetAssessmentReportResponseTypeDef,
    GetExclusionsPreviewResponseTypeDef,
    GetTelemetryMetadataResponseTypeDef,
    ListAssessmentRunAgentsResponseTypeDef,
    ListAssessmentRunsResponseTypeDef,
    ListAssessmentTargetsResponseTypeDef,
    ListAssessmentTemplatesResponseTypeDef,
    ListEventSubscriptionsResponseTypeDef,
    ListExclusionsResponseTypeDef,
    ListFindingsResponseTypeDef,
    ListRulesPackagesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PreviewAgentsResponseTypeDef,
    RemoveAttributesFromFindingsResponseTypeDef,
    StartAssessmentRunResponseTypeDef,
)

def get_structure() -> AgentPreviewTypeDef:
    return {
      ...
    }
```
